# Authors of SageMath #

[Over 800 people](https://www.sagemath.org/development-map.html) have
contributed code to the Sage library (see [src/](src/)) or have
contributed to the maintenance of the SageMath distribution (see
[build/](build/)).

See https://www.sagemath.org/development-map.html for information
about the developers and their contributions.
